==> geronimo-ca-helper-2.0.1-sources.jar: jsp/index_jsp.java <==
package jsp;

import javax.servlet.*;
import javax.servlet.http.*;
import javax.servlet.jsp.*;
import org.apache.geronimo.ca.helper.util.CAHelperUtils;

public final class index_jsp extends org.apache.jasper.runtime.HttpJspBase
    implements org.apache.jasper.runtime.JspSourceDependent {

  private static final JspFactory _jspxFactory = JspFactory.getDefaultFactory();

  private static java.util.List _jspx_dependants;

  private javax.el.ExpressionFactory _el_expressionfactory;
  private org.apache.InstanceManager _jsp_instancemanager;

  public Object getDependants() {
    return _jspx_dependants;
  }

  public void _jspInit() {
    _el_expressionfactory = _jspxFactory.getJspApplicationContext(getServletConfig().getServletContext()).getExpressionFactory();
    _jsp_instancemanager = org.apache.jasper.runtime.InstanceManagerFactory.getInstanceManager(getServletConfig());
  }

  public void _jspDestroy() {
  }

  public void _jspService(HttpServletRequest request, HttpServletResponse response)
        throws java.io.IOException, ServletException {

    PageContext pageContext = null;
    HttpSession session = null;
    ServletContext application = null;
    ServletConfig config = null;
    JspWriter out = null;
    Object page = this;
    JspWriter _jspx_out = null;
    PageContext _jspx_page_context = null;


    try {
      response.setContentType("text/html; charset=ISO-8859-1");
      pageContext = _jspxFactory.getPageContext(this, request, response,
      			null, true, 8192, true);
      _jspx_page_context = pageContext;
      application = pageContext.getServletContext();
      config = pageContext.getServletConfig();
      session = pageContext.getSession();
      out = pageContext.getOut();
      _jspx_out = out;

      out.write("<!DOCTYPE html PUBLIC \"-//W3C//DTD HTML 4.01 Transitional//EN\" \"http://www.w3.org/TR/html4/loose.dtd\">\n");

    Object certReqStore = CAHelperUtils.getCertificateRequestStore();
    Object certStore = CAHelperUtils.getCertificateStore();

      out.write("<html>\n<head>\n<meta http-equiv=\"Content-Type\" content=\"text/html; charset=ISO-8859-1\">\n<title>CA Helper Application</title>\n</head>\n<body>\n<h2>CA Helper Application</h2>\n<p>Welcome to CA Helper application. <p>\n\n");
if(certReqStore == null) {
      out.write("<p>A ceritificate request store is not available.  Application can not receive Certificate Signing Requests.</p>\n");
}
if(certStore == null) {
      out.write("<p>A ceritificate store is not available.  Application can not upload certificates.</p>\n");
}
if(certReqStore == null || certStore == null) {
      out.write("<p>Please contact the system administrator.</p>\n");
} else {
      out.write("<!-- The following is used to detect if the browser supports KEYGEN tag -->\n<div style=\"display:none\"><form name='keygentest'><keygen name=\"test\"/></form></div>\n<script>\nif(document.keygentest.elements.length == 0) {\n    document.write('Your browser does not support KEYGEN tag.  This application requires a browser that supports KEYGEN.');\n} else {\n    document.write('<p>This application allows you to submit certificate requests, download and install certificates issued by the CA.</p>');\n    document.write(\n    '<table border=\"0\">'+\n      '<tr>'+\n        '<td>&nbsp;<a href=\"requestCertificate.jsp\">Request Certificate</a>&nbsp;</td>'+\n        '<td>&nbsp;<a href=\"downloadCertificate.jsp\">Download your Certificate</a>&nbsp;</td>'+\n        '<td>&nbsp;<a href=\"downloadCACertificate.jsp\">Download CA Certificate</a>&nbsp;</td>'+\n      '</tr>'+\n    '</table>'\n    )\n}\n</script>\n");
}
      out.write("</body>\n</html>\n");
    } catch (Throwable t) {
      if (!(t instanceof SkipPageException)){
        out = _jspx_out;
        if (out != null && out.getBufferSize() != 0)
          try { out.clearBuffer(); } catch (java.io.IOException e) {}
        if (_jspx_page_context != null) _jspx_page_context.handlePageException(t);
      }
    } finally {
      _jspxFactory.releasePageContext(_jspx_page_context);
    }
  }
}

==> geronimo-ca-helper-2.1.6-sources.jar: jsp/index_jsp.java <==
package jsp;

import javax.servlet.*;
import javax.servlet.http.*;
import javax.servlet.jsp.*;
import org.apache.geronimo.ca.helper.util.CAHelperUtils;

public final class index_jsp extends org.apache.jasper.runtime.HttpJspBase
    implements org.apache.jasper.runtime.JspSourceDependent {

  private static final JspFactory _jspxFactory = JspFactory.getDefaultFactory();

  private static java.util.List _jspx_dependants;

  private javax.el.ExpressionFactory _el_expressionfactory;
  private org.apache.InstanceManager _jsp_instancemanager;

  public Object getDependants() {
    return _jspx_dependants;
  }

  public void _jspInit() {
    _el_expressionfactory = _jspxFactory.getJspApplicationContext(getServletConfig().getServletContext()).getExpressionFactory();
    _jsp_instancemanager = org.apache.jasper.runtime.InstanceManagerFactory.getInstanceManager(getServletConfig());
  }

  public void _jspDestroy() {
  }

  public void _jspService(HttpServletRequest request, HttpServletResponse response)
        throws java.io.IOException, ServletException {

    PageContext pageContext = null;
    HttpSession session = null;
    ServletContext application = null;
    ServletConfig config = null;
    JspWriter out = null;
    Object page = this;
    JspWriter _jspx_out = null;
    PageContext _jspx_page_context = null;


    try {
      response.setContentType("text/html; charset=ISO-8859-1");
      pageContext = _jspxFactory.getPageContext(this, request, response,
      			null, true, 8192, true);
      _jspx_page_context = pageContext;
      application = pageContext.getServletContext();
      config = pageContext.getServletConfig();
      session = pageContext.getSession();
      out = pageContext.getOut();
      _jspx_out = out;

      out.write("<!DOCTYPE html PUBLIC \"-//W3C//DTD HTML 4.01 Transitional//EN\" \"http://www.w3.org/TR/html4/loose.dtd\">\r\n");

    Object certReqStore = CAHelperUtils.getCertificateRequestStore();
    Object certStore = CAHelperUtils.getCertificateStore();

      out.write("<html>\r\n<head>\r\n<meta http-equiv=\"Content-Type\" content=\"text/html; charset=ISO-8859-1\">\r\n<title>CA Helper Application</title>\r\n</head>\r\n<body>\r\n<h2>CA Helper Application</h2>\r\n<p>Welcome to CA Helper application. <p>\r\n\r\n");
if(certReqStore == null) {
      out.write("<p>A certificate request store is not available.  Application can not receive Certificate Signing Requests.</p>\r\n");
}
if(certStore == null) {
      out.write("<p>A certificate store is not available.  Application can not upload certificates.</p>\r\n");
}
if(certReqStore == null || certStore == null) {
      out.write("<p>Please contact the system administrator.</p>\r\n");
} else {
      out.write("<p>This application allows you to submit certificate requests, download and install certificates issued by the CA.</p>\r\n<table border=\"0\">\r\n    <tr>\r\n        <td>&nbsp;<a href=\"requestCertificate.jsp\">Request Certificate</a>&nbsp;</td>\r\n        <td>&nbsp;<a href=\"downloadCertificate.jsp\">Download your Certificate</a>&nbsp;</td>\r\n        <td>&nbsp;<a href=\"downloadCACertificate.jsp\">Download CA Certificate</a>&nbsp;</td>\r\n    </tr>\r\n</table>\r\n");
}
      out.write("</body>\r\n</html>\r\n");
    } catch (Throwable t) {
      if (!(t instanceof SkipPageException)){
        out = _jspx_out;
        if (out != null && out.getBufferSize() != 0)
          try { out.clearBuffer(); } catch (java.io.IOException e) {}
        if (_jspx_page_context != null) _jspx_page_context.handlePageException(t);
      }
    } finally {
      _jspxFactory.releasePageContext(_jspx_page_context);
    }
  }
}
